Description Usage Arguments Examples
Generate n observations from a mixture of two normal distributions: generate U from a Bernoulli(p) distribution and if U=1, then draw Y from a normal distribution with mean mu1 and standard deviation sigma1, or if U=0, draw Y from the other normal distribution with mean mu2 and standard deviation sigma2
1 | mix_norm(p, mu1, mu2, sigma1, sigma2)
|
p |
numeric, probability that Y is drawn from a normal distribution N(mu1,sigma1) |
mu1 |
numeric, mean of first normal distribution |
mu2 |
numeric, mean of second normal distribution |
sigma1 |
numeric, standard deviation of first normal distribution |
sigma2 |
numeric, standard deviation of second normal distribution |
1 | mix_norm(0.5,-2,3,2,1.5)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.